#define ONFRONTCONNECTED 0
#define ONFRONTDISCONNECTED 1
#define ONRTNNOTICE 2
#define ONRSPERROR 3
#define ONRSPSTOCKUSERLOGIN 4
#define ONRSPSTOCKUSERLOGOUT 5
#define ONRSPSTOCKUSERPASSWORDUPDATE 6
#define ONRSPSTOCKENTRUSTORDER 7
#define ONRSPSTOCKWITHDRAWORDER 8
#define ONRSPSTOCKQRYENTRUSTORDER 9
#define ONRSPSTOCKQRYREALTIMETRADE 10
#define ONRSPSTOCKQRYSERIALTRADE 11
#define ONRSPSTOCKQRYPOSITION 12
#define ONRSPSTOCKQRYCAPITALACCOUNTINFO 13
#define ONRSPSTOCKQRYACCOUNTINFO 14
#define ONRSPSTOCKQRYSHAREHOLDERINFO 15
#define ONRSPSTOCKTRANSFERFUNDS 16
#define ONRSPSTOCKENTRUSTBATCHORDER 17
#define ONRSPSTOCKWITHDRAWBATCHORDER 18
#define ONRSPSTOCKCALCABLEENTRUSTQTY 19
#define ONRSPSTOCKCALCABLEPURCHASEETFQTY 20
#define ONRSPSTOCKQRYFREEZEFUNDSDETAIL 21
#define ONRSPSTOCKQRYFREEZESTOCKDETAIL 22
#define ONRSPSTOCKQRYTRANSFERSTOCKDETAIL 23
#define ONRSPSTOCKQRYTRANSFERFUNDSDETAIL 24
#define ONRSPSTOCKQRYSTOCKINFO 25
#define ONRSPSTOCKQRYSTOCKSTATICINFO 26
#define ONRSPSTOCKQRYTRADETIME 27
#define ONSTOCKENTRUSTORDERRTN 28
#define ONSTOCKTRADERTN 29
#define ONSTOCKWITHDRAWORDERRTN 30
#define ONRSPSOPUSERLOGIN 31
#define ONRSPSOPUSERLOGOUT 32
#define ONRSPSOPUSERPASSWORDUPDATE 33
#define ONRSPSOPENTRUSTORDER 34
#define ONRSPSOPQUOTEENTRUSTORDER 35
#define ONRSPSOPGROUPSPLIT 36
#define ONRSPSOPQRYGROUPPOSITION 37
#define ONRSPSOPLOCKOUNLOCKSTOCK 38
#define ONRSPSOPWITHDRAWORDER 39
#define ONRSPSOPQRYENTRUSTORDER 40
#define ONRSPSOPQRYSERIALTRADE 41
#define ONRSPSOPQRYPOSITION 42
#define ONRSPSOPQRYCOLLATERALPOSITION 43
#define ONRSPSOPQRYCAPITALACCOUNTINFO 44
#define ONRSPSOPQRYACCOUNTINFO 45
#define ONRSPSOPQRYSHAREHOLDERINFO 46
#define ONRSPSOPCALCABLEENTRUSTQTY 47
#define ONRSPSOPQRYABLELOCKSTOCK 48
#define ONRSPSOPQRYCONTACTINFO 49
#define ONRSPSOPEXECTUEORDER 50
#define ONRSPSOPQRYEXECASSIINFO 51
#define ONRSPSOPQRYTRADETIME 52
#define ONRSPSOPQRYEXCHANGEINFO 53
#define ONRSPSOPQRYCOMMISSION 54
#define ONRSPSOPQRYDEPOSIT 55
#define ONRSPSOPQRYCONTRACTOBJECTINFO 56
#define ONSOPENTRUSTORDERRTN 57
#define ONSOPTRADERTN 58
#define ONSOPWITHDRAWORDERRTN 59
#define ONRSPFASLUSERLOGIN 60
#define ONRSPFASLUSERLOGOUT 61
#define ONRSPFASLQRYABLEFININFO 62
#define ONRSPFASLQRYABLESLOINFO 63
#define ONRSPFASLTRANSFERCOLLATERAL 64
#define ONRSPFASLDIRECTREPAYMENT 65
#define ONRSPFASLREPAYSTOCKTRANSFER 66
#define ONRSPFASLENTRUSTCRDTORDER 67
#define ONRSPFASLENTRUSTORDER 68
#define ONRSPFASLCALCABLEENTRUSTCRDTQTY 69
#define ONRSPFASLQRYCRDTFUNDS 70
#define ONRSPFASLQRYCRDTCONTRACT 71
#define ONRSPFASLQRYCRDTCONCHANGEINFO 72
#define ONRSPFASLTRANSFERFUNDS 73
#define ONRSPFASLQRYACCOUNTINFO 74
#define ONRSPFASLQRYCAPITALACCOUNTINFO 75
#define ONRSPFASLQRYSHAREHOLDERINFO 76
#define ONRSPFASLQRYPOSITION 77
#define ONRSPFASLQRYENTRUSTORDER 78
#define ONRSPFASLQRYSERIALTRADE 79
#define ONRSPFASLQRYREALTIMETRADE 80
#define ONRSPFASLQRYFREEZEFUNDSDETAIL 81
#define ONRSPFASLQRYFREEZESTOCKDETAIL 82
#define ONRSPFASLQRYTRANSFERFUNDSDETAIL 83
#define ONRSPFASLWITHDRAWORDER 84
#define ONRSPFASLQRYSYSTEMTIME 85
#define ONRSPFASLQRYTRANSFERREDCONTRACT 86
#define ONRSPFASLDESIRABLEFUNDSOUT 87
#define ONRSPFASLQRYGUARANTEEDCONTRACT 88
#define ONRSPFASLQRYUNDERLYINGCONTRACT 89
#define ONFASLENTRUSTORDERRTN 90
#define ONFASLTRADERTN 91
#define ONFASLWITHDRAWORDERRTN 92
