int reqStockUserLogin(const dict &req);

int reqStockUserLogout(const dict &req);

int reqSOPUserLogin(const dict &req);

int reqFASLUserLogin(const dict &req);

int reqSOPUserLogout(const dict &req);

int reqFASLUserLogout(const dict &req);

int reqStockAvailableQuotQry(const dict &req);

int reqSopAvailableQuotQry(const dict &req);

int reqUserMDPasswordUpdate(const dict &req);

