DFITCSEC_BT_Stock = 0
DFITCSEC_BT_SOP = 1
DFITCSEC_BT_FASL = 2
DFITCSEC_PWT_Trade = 1
DFITCSEC_PWT_Funds = 2
DFITCSEC_PS_General = 0
DFITCSEC_PS_Special = 1
DFITCSEC_ED_Buy = 1
DFITCSEC_ED_Sell = 2
DFITCSEC_ED_RightsIssueContribution = 3
DFITCSEC_ED_RepurchaseFinancing = 4
DFITCSEC_ED_RepurchaseSecurities = 5
DFITCSEC_ED_CustodyTransfer = 7
DFITCSEC_ED_DesignateTrading = 9
DFITCSEC_ED_RevocationDesignateTrading = 10
DFITCSEC_ED_DebtToEquity = 11
DFITCSEC_ED_BondsSoldBack = 12
DFITCSEC_ED_PlacingPurchase = 14
DFITCSEC_ED_Vote = 23
DFITCSEC_ED_Purchase = 29
DFITCSEC_ED_Redemp = 30
DFITCSEC_ED_PledgeVoucherIn = 37
DFITCSEC_ED_PledgeVoucherOut = 38
DFITCSEC_ED_FundSubscribe = 41
DFITCSEC_ED_FundPurchase = 42
DFITCSEC_ED_FundRedemption = 43
DFITCSEC_ED_FundBonusSetting = 44
DFITCSEC_ED_FundConversion = 46
DFITCSEC_ED_FundSplit = 47
DFITCSEC_ED_FundMerge = 48
DFITCSEC_ED_WarrantExercise = 50
DFITCSEC_ED_FinancingToBuy = 61
DFITCSEC_ED_SellSecPayment = 62
DFITCSEC_ED_BuySecRepaySec = 63
DFITCSEC_ED_SecuritiesToSell = 64
DFITCSEC_ED_GuaranteeInto = 65
DFITCSEC_ED_GuaranteeLayOff = 66
DFITCSEC_ED_FinancingForceSelling = 71
DFITCSEC_ED_SecuritiesForceSelling = 72
DFITCSEC_ED_AcceptOffer = 76
DFITCSEC_ED_GiveUpAcceptOffer = 77
DFITCSEC_OT_LimitPrice = 0
DFITCSEC_OT_SHBESTFRTradeLeftWithdraw = 1
DFITCSEC_OT_SHBESTFRTradeLeftTLimit = 2
DFITCSEC_OT_SZOtherBestPrice = 101
DFITCSEC_OT_SZBestPrice = 102
DFITCSEC_OT_SZImdeTradeLeftWithdraw = 103
DFITCSEC_OT_SZBESTFRTradeLeftWithdraw = 104
DFITCSEC_OT_SZBESTTotalTradeOWithdraw = 105
DFITCSEC_SOP_LimitPrice = 1
DFITCSEC_SOP_LastPrice = 2
DFITCSEC_SOP_LastTLimit = 3
DFITCSEC_SOP_MineBestPrice = 4
DFITCSEC_SOP_OptimalFive = 5
DFITCSEC_AT_Company = 0
DFITCSEC_AT_Personal = 1
DFITCSEC_EI_SH = "SH"
DFITCSEC_EI_SZ = "SZ"
DFITCSTOCK_EQF_Total = 0
DFITCSTOCK_EQF_AbleWithdraw = 1
DFITCSEC_CF_EntrustSucc = "O"
DFITCSEC_CF_WithdrawSuc = "W"
DFITCSEC_CF_Withdraw = "-1"
DFITCSEC_CF_Normal = "0"
DFITCSEC_TQF_Total = 0
DFITCSEC_TQF_Trade = 1
DFITCSEC_PQF_Normal = 0
DFITCSEC_PQF_Extend = 1
DFITCSEC_FQF_Normal = 0
DFITCSEC_FQF_Extend = 1
DFITCSEC_PQF_Normal = 0
DFITCSEC_SQF_High = 1
DFITCSEC_C_RMB = "RMB"
DFITCSEC_S_USD = "USD"
DFITCSEC_S_HKD = "HKD"
DFITCSEC_FTF_In = 1
DFITCSEC_FTF_Out = 2
DFITCSEC_FFT_EntrustFreeze = 1
DFITCSEC_FFT_RealtimeTradeUnFreeze = 2
DFITCSEC_FFT_ManualFreeze = 3
DFITCSEC_FFT_ManualUnFreeze = 4
DFITCSEC_FFT_InitFunds = 50
DFITCSEC_FFT_FundsIn = 51
DFITCSEC_FFT_FundsOut = 52
DFITCSEC_SFT_EntrustFreeze = 1
DFITCSEC_SFT_IncSellQty = 2
DFITCSEC_SFT_DecSellQty = 3
DFITCSEC_SFT_ManualFreeze = 4
DFITCSEC_SFT_ClearFreeze = 5
DFITCSEC_SFT_PurchaseETFFreeze = 6
DFITCSEC_SFT_OfferFreeze = 7
DFITCSEC_SFT_ExeFreeze = 8
DFITCSEC_SFT_CollTranStandFreeze = 9
DFITCSEC_SFT_PledgeStoringFreeze = 10
DFITCSEC_SFT_INITStock = 50
DFITCSEC_SFT_StockIn = 53
DFITCSEC_SFT_StockOut = 54
DFITCSEC_ET_Phone = 1
DFITCSEC_ET_MagicCard = 2
DFITCSEC_ET_Hotkey = 4
DFITCSEC_ET_Spd = 8
DFITCSEC_ET_Remote = 16
DFITCSEC_ET_Internet = 32
DFITCSEC_ET_Mobile = 64
DFITCSEC_DR_UnDeclare = 0
DFITCSEC_DR_Declaring = 1
DFITCSEC_DR_UnTrade = 2
DFITCSEC_DR_EntrustFail = 3
DFITCSEC_DR_Confirm = 4
DFITCSEC_DR_PartTrade = 5
DFITCSEC_DR_TotalTrade = 6
DFITCSEC_DR_TradeAWithdraw = 7
DFITCSEC_DR_TotalWithdraw = 8
DFITCSEC_DR_WithdrawFail = 9
DFITCSEC_DR_ManualDeclare = 10
DFITCSEC_BDR_Declared = 1
DFITCSEC_AS_Normal = 0
DFITCSEC_AS_Freeze = 1
DFITCSEC_AS_LossReporting = 2
DFITCSEC_AS_CloseAccount = 3
DFITCSEC_AS_MicroDormancy = 6
DFITCSEC_AS_UnQualified = 7
DFITCSEC_AS_CompUnQualified = 9
DFITCSEC_TS_Normal = 0
DFITCSEC_TS_Suspend = 2
DFITCSEC_TS_CallOut = 4
DFITCSEC_AI_IDcard = 0
DFITCSEC_AI_PasPrt = 1
DFITCSEC_AI_OffCard = 2
DFITCSEC_AI_SolderCard = 3
DFITCSEC_AI_RntryPrmt = 4
DFITCSEC_AI_HusHldRgstr = 5
DFITCSEC_AI_FrignPasPrt = 6
DFITCSEC_AI_TechSupBruCode = 7
DFITCSEC_AI_BsnsLicence = 8
DFITCSEC_AI_AdminOrgan = 9
DFITCSEC_AI_SocialGrup = 10
DFITCSEC_AI_Army = 11
DFITCSEC_AI_ArmdPolice = 12
DFITCSEC_AI_SubBody = 13
DFITCSEC_AI_Foundation = 14
DFITCSEC_AI_TaiWanCard = 15
DFITCSEC_AI_HMTIDcard = 16
DFITCSEC_AI_OtherCard = 99
DFITCSEC_PSF_Sync = 0
DFITCSEC_PSF_UnSync = 1
DFITCSEC_SSP_SpecTheDay = 2
DFITCSEC_SSP_SpecRePurchase = 16
DFITCSEC_SSP_SpecOtherDay = 32
DFITCSEC_TP_BasicTrade = 1
DFITCSEC_TP_ReprchFnc = 2
DFITCSEC_TP_ReprchSecLoan = 4
DFITCSEC_TP_ETF_SubRedemp = 8
DFITCSEC_TP_WarrantTrade = 16
DFITCSEC_TP_ThreeBrdTran = 32
DFITCSEC_TP_GEM = 64
DFITCSEC_SHS_Normal = 0
DFITCSEC_SHS_Freeze = 1
DFITCSEC_SHS_LOSS = 2
DFITCSEC_SHS_Dormancy = 6
DFITCSEC_SHS_Unqualified = 7
DFITCSEC_SHS_Activation = 8
DFITCSEC_SHS_CompanyUnqualified = 9
DFITCSEC_SHS_Applying = 10
DFITCSEC_SHS_ApplyFailed = 11
DFITCSEC_SHS_VIP = 12
DFITCSEC_MA_Auxiliary = 0
DFITCSEC_MA_Master = 1
DFITCSEC_SHC_Normal = 0
DFITCSEC_SHC_ForbidBuy = 4
DFITCSEC_SHC_ForbidSell = 8
DFITCSEC_SHC_ForbidWithdraw = 64
DFITCSEC_SHC_ForbidCustodyTransfer = 128
DFITCSEC_BTF_UnBidTrade = 0
DFITCSEC_BTF_BidTrade = 1
DFITCSEC_T0_Transaction = 1
DFITCSEC_Seat_Hosting = 2
DFITCSEC_Computing_Market_Value = 8
DFITCSEC_OCF_Open = 1
DFITCSEC_OCF_Close = 2
DFITCSEC_OCF_Execute = 6
DFITCSEC_OCF_Perform = 7
DFITCSEC_OCF_RealIntenDevi = 8
DFITCSEC_OCF_ConPosiAdj = 9
DFITCSEC_OCF_SecFreeze = 10
DFITCSEC_OCF_SecThaw = 11
DFITCSEC_OCF_ForceClose = 12
DFITCSEC_OCF_Group = 19
DFITCSEC_OCF_Split = 20
DFITCSEC_OCF_ToPrePare = 21
DFITCSEC_OCF_ToCash = 22
DFITCSEC_OCF_GroupExecute = 23
DFITCSEC_CF_UnCovered = 0
DFITCSEC_CF_Covered = 1
DFITCSEC_CF_CoveredPrior = 2
DFITCSEC_OE_NONE = 0
DFITCSEC_OE_FAK = 1
DFITCSEC_OE_FOK = 2
DFITCSEC_OC_GeneralOrder = 0
DFITCSEC_OC_ManualCloseOrder = 1
DFITCSEC_OC_AutoCloseOrder = 8
DFITCSEC_OT_CALL = 1
DFITCSEC_OT_PUT = 2
DFITCSEC_COT_STOCK = 1
DFITCSEC_COT_ETF = 2
DFITCSEC_AT_Personal = 1
DFITCSEC_AT_Organization = 2
DFITCSEC_AT_Selfoperation = 3
DFITCSEC_AT_Marketmaker = 4
DFITCSEC_AT_member = 0
DFITCSEC_AP_PrhbtDeposit = 1
DFITCSEC_AP_PrhbtDrawMoney = 2
DFITCSEC_AP_PrhbtBankTran = 4
DFITCSEC_AP_PrhbtTransfer = 8
DFITCSEC_AP_PrhbtCancelSpecTran = 16
DFITCSEC_AP_PrhbtCancelAcc = 32
DFITCSEC_AP_PrhbtTakePos = 64
DFITCSEC_AP_PrhbtClsPos = 128
DFITCSEC_AP_PrhbtSngFamFunTran = 256
DFITCSEC_CULF_Check = 0
DFITCSEC_CULF_UnChec = 1
DFITCSEC_ET_US = 0
DFITCSEC_ET_Europe = 1
DFITCSEC_DT_Real = 1
DFITCSEC_DT_Cash = 2
DFITCSEC_OL_Permit = 0
DFITCSEC_OL_UnPermit = 1
DFITCSEC_STF_Normal = 0
DFITCSEC_STF_Stop = 1
DFITCSEC_STF_Normal = 0
DFITCSEC_STF_Stop = 1
DFITCSEC_STF_Issue = 2
DFITCSEC_STF_FirstList = 3
DFITCSEC_STF_UnList = 4
DFITCSEC_SLF_A = 'A'
DFITCSEC_SLF_E = 'E'
DFITCSEC_SLF_D = 'D'
DFITCSEC_COS_Normal = 0
DFITCSEC_COS_Suspend = 1
DFITCSEC_COS_Cancel = 2
DFITCSEC_L_EXCHANGE = 1
DFITCSEC_L_COMPANY = 2
DFITCSEC_L_CUSTOMER = 3
DFITCSEC_RT_ObjectType = 1
DFITCSEC_RT_ObjectID = 2
DFITCSEC_RT_OptionID = 3
DFITCSEC_CCQF_Queryall = 0
DFITCSEC_CCQF_Endoftheday = 1
DFITCSEC_CCQF_Unfinished = 2
DFITCSEC_CCS_UnSettle = 0
DFITCSEC_CCS_UnClear = 1
DFITCSEC_CCS_Settle = 3
DFITCSEC_CF_TradeCause = 1
DFITCSEC_CF_ClearCause = 2
DFITCSEC_CF_ComCause = 3
DFITCSEC_HKEL_NormalStolk = 0
DFITCSEC_HKEL_Bid = 1
DFITCSEC_HKEL_OpeningBid = 2
DFITCSEC_HKEL_OddStock = 3
DFITCSEC_HKOT_GFT = 0
DFITCSEC_HKOT_FOK = 4
DFITCSEC_ORDER_SUCCESS = 0
DFITCSEC_ORDER_FAIL = 1
DFITCSEC_EGT_ToPrepare = 1
DFITCSEC_EGT_BullBuy = 2
DFITCSEC_EGT_BearSell = 3
DFITCSEC_EGT_BullSell = 4
DFITCSEC_EGT_BearBuy = 5
DFITCSEC_EGT_ShortStraddle = 6
DFITCSEC_EGT_WideStraddle = 7
DFITCSEC_EGT_CoveredToCash = 8
DFITCSEC_CAR_NotAdj = 0
DFITCSEC_CAR_Adj = 1
DFITCSEC_CER_NotExpire = 0
DFITCSEC_CER_WillExpire = 1
DFITCSEC_COMPRESS_FALSE = 0
DFITCSEC_COMPRESS_TRUE = 1
DFITCSEC_COLLECTTYPE_APEX = 1
DFITCSEC_COLLECTTYPE_HS = 2
DFITCSEC_COLLECTTYPE_KD = 3
DFITCSEC_COLLECTTYPE_KS = 4
DFITCSEC_CONNECT_DIRECT = 1
DFITCSEC_CONNECT_RELAY = 2
